/*
Copyright 2011 Johan Maasing

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package nu.zoom.catonine.swing.tail;

import java.awt.event.ActionEvent;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;

import javax.swing.ImageIcon;

import nu.zoom.swing.action.AbstractTypedAction;
import nu.zoom.ui.Resources;
import nu.zoom.ui.Resources.ResourceNotFoundException;

/**
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 * 
 */
public class ToggleGutterAction extends AbstractTypedAction {
	private static final long serialVersionUID = -2785171639945471087L;
	private final TailPane tailPane;
	private final String showGutterText;
	private final String showGutterTooltip;
	private final ImageIcon showGutterIcon;

	public ToggleGutterAction(final TailPane tailPane, final Resources resources) throws ResourceNotFoundException {
		this.tailPane = tailPane;
		this.showGutterText = resources.getMessage("nu.zoom.catonine.tail.gutter");
		this.showGutterTooltip = resources.getMessage("nu.zoom.catonine.tail.gutter.tt");
		this.showGutterIcon = resources.getIcon("nu.zoom.catonine.tail.gutter.icon");
		setMnemonicKey(KeyEvent.VK_G);
		setAcceleratorKey(KeyEvent.VK_G, InputEvent.CTRL_DOWN_MASK);
		setName(this.showGutterText);
		setToolTip(this.showGutterTooltip);
		setIcon(this.showGutterIcon);
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		boolean newValue = !tailPane.isGutterVisible();
		tailPane.setGutterVisible(newValue);
	}

}
