/*
Copyright 2011 Johan Maasing

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package nu.zoom.catonine.swing.tail;

import java.awt.event.ActionEvent;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;

import javax.swing.ImageIcon;

import nu.zoom.swing.action.AbstractTypedAction;
import nu.zoom.ui.Resources;
import nu.zoom.ui.Resources.ResourceNotFoundException;

/**
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 * 
 */
public class ToggleWrapAction extends AbstractTypedAction {
	private static final long serialVersionUID = -830928211003030643L;
	private final TailPane tailPane;
	private final String enableWrapText;
	private final String enableWrapTooltip;
	private final ImageIcon enableWrapIcon;
	private final String disableWrapText;
	private final String disableWrapTooltip;
	private final ImageIcon disableWrapIcon;

	public ToggleWrapAction(final TailPane tailPane, final Resources messages) throws ResourceNotFoundException {
		this.tailPane = tailPane;
		this.enableWrapText = messages.getMessage("nu.zoom.catonine.tail.wrap.enable");
		this.enableWrapTooltip = messages.getMessage("nu.zoom.catonine.tail.wrap.enable.tt");
		this.enableWrapIcon = messages.getIcon("nu.zoom.catonine.tail.wrap.enable.icon");
		this.disableWrapText = messages.getMessage("nu.zoom.catonine.tail.wrap.disable");
		this.disableWrapTooltip = messages.getMessage("nu.zoom.catonine.tail.wrap.disable.tt");
		this.disableWrapIcon = messages.getIcon("nu.zoom.catonine.tail.wrap.disable.icon");
		setMnemonicKey(KeyEvent.VK_A);
		setAcceleratorKey(KeyEvent.VK_A, InputEvent.CTRL_DOWN_MASK);
		stateChanged(tailPane.isWrap());
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		this.tailPane.toggleWrap(this);
	}

	void stateChanged(final boolean isWrap) {
		if (isWrap) {
			setName(this.disableWrapText);
			setToolTip(this.disableWrapTooltip);
			setIcon(this.disableWrapIcon);
		} else {
			setName(this.enableWrapText);
			setToolTip(this.enableWrapTooltip);
			setIcon(this.enableWrapIcon);
		}
	}

}
