/*
Copyright 2011 Johan Maasing

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package nu.zoom.catonine.swing.tail.gutter;

import java.util.LinkedList;
import java.util.List;

import nu.zoom.catonine.prefs.Preferences;
import nu.zoom.catonine.swing.tail.FoldedDocumentLogEntry;
import nu.zoom.catonine.swing.tail.TruncatingTailingDocument;

/**
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 * 
 */
public class GutterDocument extends TruncatingTailingDocument {
	private static final long serialVersionUID = -2612116779513433678L;

	public GutterDocument(Preferences preferences) {
		super(preferences);
	}

	protected synchronized List<FoldedDocumentLogEntry> getIntersectingLogEntries(final int startPosition,
			final int endPosition) {
		LinkedList<FoldedDocumentLogEntry> intersectingEntries = new LinkedList<FoldedDocumentLogEntry>();
		for (FoldedDocumentLogEntry documentLogEntry : this.content) {
			if ((documentLogEntry.documentOffset + documentLogEntry.documentLength > startPosition)
					&& (documentLogEntry.documentOffset < endPosition)) {
				intersectingEntries.add(documentLogEntry);
			}
			// Fail fast when entries are larger than endpoint
			if (documentLogEntry.documentOffset > endPosition) {
				break;
			}
		}
		return intersectingEntries;
	}
}
